@@ -2,7 +2,8 @@
 ## Martin Schlather, schlather@math.uni-mannheim.de
 ##
 ##
-## Copyright (C) 2015 Martin Schlather
+## Copyright (C) 2012 -- 2014 Alexander Malinowski & Martin Schlather
+##               2015 -- 2017 Martin Schlather
 ##
 ## This program is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU General Public License
@@ -77,6 +78,7 @@ RFspatialGridDataFrame <- function(grid, data,
                                    RFparams=list(n=1, vdim=1)) {
   
   grid <- convert2GridTopology(grid)
+#  save(file="dataframe.rda", grid,  data, proj4string)
   tmp <- sp::SpatialGridDataFrame(grid=grid,
                                   data = if (is.data.frame(data)) data else
                                   data.frame(data),
@@ -180,7 +182,7 @@ brack2 <- function(x, i, j, ..., value) {
 
 
 
-cbind_RFsp <- function(...) {  ##copied from sp package
+cbind_RFsp <- function(...) {  ##copied from 'sp' 
   stop.ifnot.equal = function(a, b) {
     res = all.equal(a@grid, b@grid)
     if (!is.logical(res) || !res)
@@ -203,7 +205,7 @@ cbind_RFsp <- function(...) {  ##copied from sp package
   gr
 }
 
-cbind_RFspPoints <- function(...) {  ##copied from sp package
+cbind_RFspPoints <- function(...) {  ##copied from 'sp'
   stop.ifnot.equal = function(a, b) {
     res = all.equal(a@coords, b@coords)
     if (!is.logical(res) || !res)
@@ -486,7 +488,7 @@ conventional2RFspDataFrame <-
   ## may be NULL, if called from 'RFsimulate', the left hand side of model, if
   ## model is a formula, is passed to 'varnames'
   attributes(data)$varnames <- NULL
-  
+   
   ## grid case
   if (length(coords) == 0) {# war is.null(coords) -- erfasst coords=list() nicht
     grid <- convert2GridTopology(gridTopology) 
@@ -519,6 +521,8 @@ conventional2RFspDataFrame <-
       perm <- c( 1+(1:timespacedim), 1, if (n>1) timespacedim+2 else NULL)
       data <- aperm(data, perm=perm)
     }
+
+     
     if (timespacedim==1)
       call <- "RFgridDataFrame"
     else {
@@ -528,6 +532,7 @@ conventional2RFspDataFrame <-
     }
   }
   
+
   ## coords case
   if (is.null(gridTopology)){
     if (vdim>1 && vdim_close_together){
@@ -541,7 +546,6 @@ conventional2RFspDataFrame <-
   }
 
   
-  
   ## in both cases:
   dim(data) <- NULL
   data <- as.data.frame(matrix(data, ncol=n*vdim))
@@ -557,9 +561,10 @@ conventional2RFspDataFrame <-
     else names(data) <- NULL
   
   ## Print(call, varnames, names(data), coords, is.null(coords))
-
+ 
   if (is.null(coords)){
-#   Print(call, data=data, grid, RFparams=list(n=n, vdim=vdim, T=T))
+#
+#    Print(call, data=data, grid, RFparams=list(n=n, vdim=vdim, T=T))
 
     do.call(call, args=list(data=data, grid=grid,
                       RFparams=list(n=n, vdim=vdim, T=T)))
